@@ -1,5 +1,5 @@
 package Net::Google::Analytics::DataFeedResponse;
-our $VERSION = '0.10001';
+our $VERSION = '0.10002';
 use strict;
 
 use base qw(Net::Google::Analytics::FeedResponse);
@@ -32,6 +32,10 @@ sub _parse_entry {
 sub project {
     my ($self, $projection) = @_;
 
+    # Projected dimensions and the sum of their metrics are collected in
+    # hash %proj_metrics. The keys of the hash are the the projected
+    # dimension values joined with zero bytes.
+
     my %proj_metrics;
 
     for my $entry (@{ $self->entries }) {
@@ -46,15 +50,15 @@ sub project {
         }
         else {
             for (my $i=0; $i<@$metrics; ++$i) {
-                if ($metrics->[$i]->type eq 'integer') {
-                    $proj_metrics->[$i]->value(
-                        $proj_metrics->[$i]->value + $metrics->[$i]->value
-                    );
-                }
+                $proj_metrics->[$i]->value(
+                    $proj_metrics->[$i]->value + $metrics->[$i]->value
+                );
             }
         }
     }
 
+    # iterate over %proj_metrics and push new entries onto @proj_entries
+
     my @proj_entries;
 
     while (my ($key, $metrics) = each(%proj_metrics)) {
